pub enum CommentLinePosition {
EndOfLine,
OwnLine,
}Expand description
The position of a comment in the source text.
Variants
EndOfLine
A comment that is on the same line as the preceding token and is separated by at least one line break from the following token.
Examples
End of line
a; # comment
b;# comment is an end of line comments because it is separated by at least one line break from the following token b.
Comments that not only end, but also start on a new line are OwnLine comments.
OwnLine
A Comment that is separated by at least one line break from the preceding token.
Examples
a;
# comment
b;# comment line comments because they are separated by one line break from the preceding token a.
Implementations
Sourceimpl CommentLinePosition
impl CommentLinePosition
pub const fn is_own_line(self) -> bool
pub const fn is_end_of_line(self) -> bool