SimpleTokenKind

Enum SimpleTokenKind 

pub enum SimpleTokenKind {
Show 90 variants Comment, Whitespace, EndOfFile, Continuation, Newline, LParen, RParen, LBrace, RBrace, LBracket, RBracket, Comma, Colon, Semi, Slash, Star, Dot, Plus, Minus, Equals, Greater, Less, Percent, Ampersand, Circumflex, Vbar, At, Tilde, EqEqual, NotEqual, LessEqual, GreaterEqual, LeftShift, RightShift, DoubleStar, DoubleStarEqual, PlusEqual, MinusEqual, StarEqual, SlashEqual, PercentEqual, AmperEqual, VbarEqual, CircumflexEqual, LeftShiftEqual, RightShiftEqual, DoubleSlash, DoubleSlashEqual, ColonEqual, Ellipsis, AtEqual, RArrow, And, As, Assert, Async, Await, Break, Class, Continue, Def, Del, Elif, Else, Except, Finally, For, From, Global, If, Import, In, Is, Lambda, Nonlocal, Not, Or, Pass, Raise, Return, Try, While, Match, Type, Case, With, Yield, Name, Other, Bogus,
}

Variants



Comment

A comment, not including the trailing new line.



Whitespace

Sequence of ’ ’ or ‘\t’



EndOfFile

Start or end of the file



Continuation

\\



Newline

\n or \r or \r\n



LParen

(



RParen

)



LBrace

{



RBrace

}



LBracket

[



RBracket

]



Comma

,



Colon

:



Semi

;



Slash

/



Star

*



Dot

.



Plus

+



Minus

-



Equals

=



Greater

>



Less

<



Percent

%



Ampersand

&



Circumflex

^



Vbar

|



At

@



Tilde

~



EqEqual

==



NotEqual

!=



LessEqual

<=



GreaterEqual

>=



LeftShift

<<



RightShift

>>



DoubleStar

**



DoubleStarEqual

**=



PlusEqual

+=



MinusEqual

-=



StarEqual

*=



SlashEqual

/=



PercentEqual

%=



AmperEqual

&=



VbarEqual

|=



CircumflexEqual

^=



LeftShiftEqual

<<=



RightShiftEqual

>>=



DoubleSlash

//



DoubleSlashEqual

//=



ColonEqual

:=



Ellipsis

...



AtEqual

@=



RArrow

->



And

and



As

as



Assert

assert



Async

async



Await

await



Break

break



Class

class



Continue

continue



Def

def



Del

del



Elif

elif



Else

else



Except

except



Finally

finally



For

for



From

from



Global

global



If

if



Import

import



In

in



Is

is



Lambda

lambda



Nonlocal

nonlocal



Not

not



Or

or



Pass

pass



Raise

raise



Return

return



Try

try



While

while



Match

match



Type

type



Case

case



With

with



Yield

yield



Name

An identifier or keyword.



Other

Any other non trivia token.



Bogus

Returned for each character after SimpleTokenKind::Other has been returned once.

Implementations

Source

impl SimpleTokenKind

pub const fn is_trivia(self) -> bool

pub const fn is_comment(self) -> bool